summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/timeperiod.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/timeperiod.h')
-rw-r--r--kalarm/lib/timeperiod.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/kalarm/lib/timeperiod.h b/kalarm/lib/timeperiod.h
index f6f6304fb..86b663798 100644
--- a/kalarm/lib/timeperiod.h
+++ b/kalarm/lib/timeperiod.h
@@ -47,9 +47,10 @@ class TimeSpinBox;
*
* @author David Jarvie <software@astrojar.org.uk>
*/
-class TimePeriod : public QHBox
+class TimePeriod : public TQHBox
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Units for the time period.
* @li MINUTES - the time period is entered as a number of minutes.
@@ -64,10 +65,10 @@ class TimePeriod : public QHBox
* being allowed as units; only days and weeks can ever be used,
* regardless of other method calls. Set true to allow minutes,
* hours/minutes, days or weeks as units.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- TimePeriod(bool allowMinute, TQWidget* parent, const char* name = 0);
+ TimePeriod(bool allowMinute, TQWidget* tqparent, const char* name = 0);
/** Returns true if the widget is read only. */
bool isReadOnly() const { return mReadOnly; }
/** Sets whether the widget is read-only for the user. If read-only,
@@ -103,7 +104,7 @@ class TimePeriod : public QHBox
/** Sets separate WhatsThis texts for the count spin boxes and the units combo box.
* If @p hourMin is omitted, both spin boxes are set to the same WhatsThis text.
*/
- void setWhatsThis(const TQString& units, const TQString& dayWeek, const TQString& hourMin = TQString::null);
+ void setWhatsThis(const TQString& units, const TQString& dayWeek, const TQString& hourMin = TQString());
static TQString i18n_minutes(); // text of 'minutes' units, lower case
static TQString i18n_Minutes(); // text of 'Minutes' units, initial capitals
@@ -64,10 +65,10 @@ class TimePeriod : public QHBox
* regardless of other method calls. Set true to allow minutes,
* hours/minutes, days or weeks as units.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/